@@ -15,6 +15,7 @@
 import json
 from typing import Any, Union
 from supertokens_python.framework.request import BaseRequest
+from urllib.parse import parse_qsl
 
 
 class DjangoRequest(BaseRequest):
@@ -27,8 +28,11 @@ class DjangoRequest(BaseRequest):
         return self.request.GET.get(key, default)
 
     async def json(self):
-        body = json.loads(self.request.body)
-        return body
+        try:
+            body = json.loads(self.request.body)
+            return body
+        except Exception:
+            return {}
 
     def method(self) -> str:
         return self.request.method
@@ -52,3 +56,6 @@ class DjangoRequest(BaseRequest):
 
     def get_path(self) -> str:
         return self.request.path
+
+    async def form_data(self):
+        return dict(parse_qsl(self.request.body.decode('utf-8')))
