@@ -22,5 +22,5 @@ async def handle_signout_api(api_implementation: APIInterface, api_options: APIO
     if api_implementation.disable_signout_post or api_implementation.signout_post is None:
         return None
     response = await api_implementation.signout_post(api_options)
-    api_options.response.set_content(response.to_json())
+    api_options.response.set_json_content(response.to_json())
     return api_options.response
