@@ -16,6 +16,7 @@ from abc import ABC, abstractmethod
 from typing import Union, List, TYPE_CHECKING
 if TYPE_CHECKING:
     from supertokens_python.framework import BaseRequest, BaseResponse
+    from supertokens_python.recipe.jwt.interfaces import RecipeInterface as JWTRecipeInterface
     from .utils import SessionConfig
     from .session_class import Session
 
@@ -98,12 +99,14 @@ class SignOutOkayResponse(SignOutResponse):
 
 class APIOptions:
     def __init__(self, request: BaseRequest, response: Union[BaseResponse, None],
-                 recipe_id: str, config: SessionConfig, recipe_implementation: RecipeInterface):
+                 recipe_id: str, config: SessionConfig, recipe_implementation: RecipeInterface,
+                 jwt_recipe_implementation: Union[JWTRecipeInterface, None]):
         self.request = request
         self.response = response
         self.recipe_id = recipe_id
         self.config = config
         self.recipe_implementation = recipe_implementation
+        self.jwt_recipe_implementation = jwt_recipe_implementation
 
 
 class APIInterface(ABC):
